Documentation
¶
Index ¶
Constants ¶
const ( EncNone = "NONE" EncAes = "AES" )
Encryption types
const ( CompNone = "NONE" CompGzip = "GZIP" CompZip = "ZIP" )
Compression algorithm types
const ( FormatJSON = "JSON" FormatXML = "XML" FormatSerialized = "SERIALIZED" FormatIoTCoreJSON = "IOTCORE_JSON" FormatAzureJSON = "AZURE_JSON" FormatCSV = "CSV" )
Data format types
const ( DestMQTT = "MQTT_TOPIC" DestZMQ = "ZMQ_TOPIC" DestIotCoreMQTT = "IOTCORE_TOPIC" DestAzureMQTT = "AZURE_TOPIC" DestRest = "REST_ENDPOINT" )
Export destination types
const ( NotifyUpdateAdd = "add" NotifyUpdateUpdate = "update" NotifyUpdateDelete = "delete" )
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type EncryptionDetails ¶
type EncryptionDetails struct {
Algo string `bson:"encryptionAlgorithm,omitempty" json:"encryptionAlgorithm,omitempty"`
Key string `bson:"encryptionKey,omitempty" json:"encryptionKey,omitempty"`
InitVector string `bson:"initializingVector,omitempty" json:"initializingVector,omitempty"`
}
EncryptionDetails - Provides details for encryption of export data per client request
type Filter ¶
type Filter struct {
DeviceIDs []string `bson:"deviceIdentifiers,omitempty" json:"deviceIdentifiers,omitempty"`
ValueDescriptorIDs []string `bson:"valueDescriptorIdentifiers,omitempty" json:"valueDescriptorIdentifiers,omitempty"`
}
Filter - Specifies the client filters on reading data
type NotifyUpdate ¶
type Registration ¶
type Registration struct {
ID bson.ObjectId `bson:"_id,omitempty" json:"_id,omitempty"`
Created int64 `json:"created"`
Modified int64 `json:"modified"`
Origin int64 `json:"origin"`
Name string `json:"name,omitempty"`
Addressable models.Addressable `json:"addressable,omitempty"`
Format string `json:"format,omitempty"`
Filter Filter `json:"filter,omitempty"`
Encryption EncryptionDetails `json:"encryption,omitempty"`
Compression string `json:"compression,omitempty"`
Enable bool `json:"enable"`
Destination string `json:"destination,omitempty"`
}
Registration - Defines the registration details on the part of north side export clients
func (*Registration) Validate ¶
func (reg *Registration) Validate() bool
Click to show internal directories.
Click to hide internal directories.